Class: Pod::Command::Download
- Inherits:
-
Command
- Object
- Command
- Pod::Command::Download
- Defined in:
- lib/cocoapods-aqara-localzedLoader/command/localzedLoader.rb
Overview
TODO:
Create a PR to add your plugin to CocoaPods/cocoapods.org
in the plugins.json file, once your plugin is released.
This is an example of a cocoapods plugin adding a top-level subcommand to the 'pod' command.
You can also create subcommands of existing or new commands. Say you
wanted to add a subcommand to list to show newly deprecated pods,
(e.g. pod list deprecated), there are a few things that would need
to change.
- move this file to
lib/pod/command/list/deprecated.rband update the class to exist in the the Pod::Command::List namespace - change this class to extend from
Listinstead ofCommand. This tells the plugin system that it is a subcommand oflist. - edit
lib/cocoapods_plugins.rbto require this file
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(argv) ⇒ Download
constructor
A new instance of Download.
- #run ⇒ Object
Constructor Details
#initialize(argv) ⇒ Download
Returns a new instance of Download.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/cocoapods-aqara-localzedLoader/command/localzedLoader.rb', line 30 def initialize(argv) super # puts "初始化:#{argv}" project_directory = argv.option('project-directory') @crowdin_token = argv.option('crowdin-token') || ENV['CROWDIN_ACCESS_TOKEN'] puts project_directory project_directory = Dir.pwd if project_directory.nil? puts project_directory @project_directory = Pathname.new(project_directory). puts project_directory end |
Class Method Details
.options ⇒ Object
42 43 44 45 46 47 |
# File 'lib/cocoapods-aqara-localzedLoader/command/localzedLoader.rb', line 42 def self. [ ['--project-directory=/project/dir/', 'The path to the root of the project directory'], ['--crowdin-token=TOKEN', 'Crowdin access token for downloading translations'] ].concat(super) end |
Instance Method Details
#run ⇒ Object
48 49 50 51 |
# File 'lib/cocoapods-aqara-localzedLoader/command/localzedLoader.rb', line 48 def run UI.puts "项目路径 #{@project_directory}" BundleGenerater.generate(@project_directory, @crowdin_token) end |